@@ -419,7 +419,7 @@ class cs_compile(object):
             if f_base == 'cs_user_initialization.f90':
                 o_name = "cs_f_user_initialization.o"
                 cmd += ["-o", o_name]
-            if f == 'cs_user_physical_properties.f90':
+            if f_base == 'cs_user_physical_properties.f90':
                 o_name = "cs_f_user_physical_properties.o"
                 cmd += ["-o", o_name]
             if f_base == 'cs_user_porosity.f90':
