@@ -446,9 +446,7 @@ Boundary conditions
 Numerical parameters
     Global parameters
     Equation parameters
-    Time step
-    Pseudo-Time step
-    Steady flow management
+    Time settings
 Calculation control
     Time averages
     Output control
@@ -461,6 +459,7 @@ Calculation management
     Start/Restart
     Performance tuning
     Prepare batch calculation
+    OpenTurns study
 """
         return tree
 
@@ -665,11 +664,10 @@ Calculation management
         self.setRowClose(self.tr('Conjugate heat transfer'))
         self.setRowClose(self.tr('Atmospheric flows'))
         self.setRowClose(self.tr('Particles boundary conditions'))
-        self.setRowClose(self.tr('Steady flow management'))
         # self.setRowClose(self.tr('Surface solution control'))
-        self.setRowClose(self.tr('Time step'))
-        self.setRowClose(self.tr('Pseudo-Time step'))
+        self.setRowClose(self.tr('Time settings'))
         self.setRowClose(self.tr('Fluid structure interaction'))
+        self.setRowClose(self.tr('Initialization'))
         self.setRowClose(self.tr('Source terms'))
         self.setRowClose(self.tr('Head losses'))
         self.setRowClose(self.tr('Porosity'))
@@ -693,6 +691,27 @@ Calculation management
             self.setRowClose(self.tr('Profiles'))
             self.setRowClose(self.tr('Balance by zone'))
             self.setRowClose(self.tr('Fans'))
+            self.setRowClose(self.tr('OpenTurns study'))
+            self.setRowOpen(self.tr('Prepare batch calculation'))
+            return
+        elif case['oturns'] == True:
+            self.setRowClose(self.tr('Thermophysical models'))
+            self.setRowClose(self.tr('Physical properties'))
+            self.setRowClose(self.tr('Volume conditions'))
+            self.setRowClose(self.tr('Particles and droplets tracking'))
+            self.setRowClose(self.tr('Boundary conditions'))
+            self.setRowClose(self.tr('Numerical parameters'))
+            self.setRowClose(self.tr('Start/Restart'))
+            self.setRowClose(self.tr('Time averages'))
+            self.setRowClose(self.tr('Volume solution control'))
+            self.setRowClose(self.tr('Surface solution control'))
+            self.setRowClose(self.tr('Lagrangian solution control'))
+            self.setRowClose(self.tr('Profiles'))
+            self.setRowClose(self.tr('Balance by zone'))
+            self.setRowClose(self.tr('Fans'))
+            self.setRowOpen(self.tr('Notebook'))
+            self.setRowOpen(self.tr('OpenTurns study'))
+            self.setRowClose(self.tr('Prepare batch calculation'))
             return
         else:
             self.setRowOpen(self.tr('Notebook'))
@@ -710,34 +729,12 @@ Calculation management
             self.setRowOpen(self.tr('Profiles'))
             self.setRowOpen(self.tr('Balance by zone'))
             self.setRowOpen(self.tr('Fans'))
+            self.setRowOpen(self.tr('Prepare batch calculation'))
+            self.setRowClose(self.tr('OpenTurns study'))
 
-        # Steady flow management
+        # Time step management
 
-        nodeanal = case.xmlGetNode('analysis_control')
-        nodeSteady = nodeanal.xmlGetNode('steady_management')
-        node_np = case.xmlGetNode('numerical_parameters')
-        nodeCouplingAlgo = node_np.xmlGetNode('velocity_pressure_algo')
-
-        if nodeSteady['status'] == 'on':
-            if nodeCouplingAlgo:
-                value = nodeCouplingAlgo['choice']
-                if value == 'simple':
-                    self.setRowClose(self.tr('Time step'))
-                    self.setRowClose(self.tr('Pseudo-Time step'))
-                    self.setRowOpen(self.tr('Steady flow management'))
-                else:
-                    self.setRowClose(self.tr('Time step'))
-                    self.setRowOpen(self.tr('Pseudo-Time step'))
-                    self.setRowClose(self.tr('Steady flow management'))
-            else:
-                self.setRowClose(self.tr('Time step'))
-                self.setRowOpen(self.tr('Pseudo-Time step'))
-                self.setRowClose(self.tr('Steady flow management'))
-        else:
-            nodeSteady['status'] = 'off'
-            self.setRowClose(self.tr('Steady flow management'))
-            self.setRowOpen(self.tr('Time step'))
-            self.setRowClose(self.tr('Pseudo-Time step'))
+        self.setRowOpen(self.tr('Time settings'))
 
         # Multi-phase flow
 
@@ -843,12 +840,15 @@ Calculation management
         # Source terms view
         node_domain = case.xmlGetNode('solution_domain')
         node_vol = node_domain.xmlGetNode('volumic_conditions')
+        nb_zone_init = 0
         nb_zone = 0
         nb_zone_losses = 0
         nb_zone_porosity = 0
         nb_zone_groundwater = 0
 
         for node in node_vol.xmlGetChildNodeList('zone'):
+            if (node['initialization'] == 'on'):
+                nb_zone_init = nb_zone_init + 1
             if node['momentum_source_term'] == 'on':
                 nb_zone = nb_zone + 1
             elif node['mass_source_term'] == 'on':
@@ -864,6 +864,8 @@ Calculation management
             if node['groundwater_law'] == 'on':
                 nb_zone_groundwater = nb_zone_groundwater + 1
 
+        if nb_zone_init > 0:
+            self.setRowOpen(self.tr('Initialization'))
         if nb_zone > 0:
             self.setRowOpen(self.tr('Source terms'))
         if nb_zone_losses > 0:
