@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -87,9 +87,7 @@ class XMLmodel(Variables):
             nodeList.append(nodeTurb.xmlGetNode('variable', name='epsilon'))
 
         elif model in ('Rij-epsilon', 'Rij-SSG', 'Rij-EBRSM'):
-            for var in ('r11', 'r22', 'r33',
-                        'r12', 'r13', 'r23',
-                        'epsilon'):
+            for var in ('rij', 'epsilon'):
                 nodeList.append(nodeTurb.xmlGetNode('variable', name=var))
             if model in ('Rij-EBRSM'):
                 nodeList.append(nodeTurb.xmlGetNode('variable', name='alpha'))
@@ -115,7 +113,9 @@ class XMLmodel(Variables):
         nodeList = []
 
         if model != 'off':
-            nodeList.append(nodeTurb.xmlGetNode('property', name='turbulent_viscosity'))
+            nodeTurbVisc = nodeTurb.xmlGetNode('property', name='turbulent_viscosity')
+            if nodeTurbVisc:
+                nodeList.append(nodeTurbVisc)
 
         if model == 'LES_dynamique':
             nodeList.append(nodeTurb.xmlGetNode('property', name='smagorinsky_constant^2'))
