@@ -53,7 +53,6 @@ from code_saturne.Base.QtPage import from_qvariant, to_text_string
 from code_saturne.Pages.NumericalParamEquationForm import Ui_NumericalParamEquationForm
 from code_saturne.Pages.NumericalParamEquationModel import NumericalParamEquationModel
 from code_saturne.Pages.TurbulenceModel import TurbulenceModel
-from code_saturne.Pages.SteadyManagementModel import SteadyManagementModel
 
 #-------------------------------------------------------------------------------
 # log config
@@ -122,6 +121,7 @@ class SolverChoiceDelegate(QItemDelegate):
         mg = index.model().dataSolver[index.row()]['mg']
         editor.addItem("Automatic")
         editor.addItem("Conjugate gradient")
+        editor.addItem("Flexible conjugate gradient")
         editor.addItem("Inexact conjugate gradient")
         editor.addItem("Jacobi")
         editor.addItem("BiCGstab")
@@ -131,7 +131,8 @@ class SolverChoiceDelegate(QItemDelegate):
         editor.addItem("Symmetric Gauss Seidel")
         editor.addItem("conjugate residual")
         if mg:
-            editor.addItem("Multigrid")
+            editor.addItem("Multigrid, V-cycle")
+            editor.addItem("Multigrid, K-cycle")
         editor.installEventFilter(self)
         return editor
 
@@ -139,15 +140,17 @@ class SolverChoiceDelegate(QItemDelegate):
     def setEditorData(self, comboBox, index):
         dico = {"automatic": 0,
                 "conjugate_gradient": 1,
-                "inexact_conjugate_gradient": 2,
-                "jacobi": 3,
-                "bi_cgstab": 4,
-                "bi_cgstab2": 5,
-                "gmres": 6,
-                "gauss_seidel": 7,
-                "symmetric_gauss_seidel": 8,
-                "PCR3": 9,
-                "multigrid": 10}
+                "flexible_conjugate_gradient": 2,
+                "inexact_conjugate_gradient": 3,
+                "jacobi": 4,
+                "bi_cgstab": 5,
+                "bi_cgstab2": 6,
+                "gmres": 7,
+                "gauss_seidel": 8,
+                "symmetric_gauss_seidel": 9,
+                "PCR3": 10,
+                "multigrid": 11,
+                "multigrid_k_cycle": 12}
         row = index.row()
         string = index.model().dataSolver[row]['iresol']
         idx = dico[string]
@@ -180,12 +183,13 @@ class PreconditioningChoiceDelegate(QItemDelegate):
 
         editor.addItem("Automatic")
         editor.addItem("None")
-        editor.addItem("Multigrid")
+        editor.addItem("Multigrid, V-cycle")
+        editor.addItem("Multigrid, K-cycle")
         editor.addItem("Jacobi")
         editor.addItem("Polynomial")
 
         solver = index.model().dataSolver[index.row()]['iresol']
-        if solver == 'multigrid':
+        if solver in ('multigrid', 'multigrid_k_cycle'):
             editor.model().item(1).setEnabled(False)
         editor.installEventFilter(self)
         return editor
@@ -218,12 +222,13 @@ class BlendingFactorDelegate(QItemDelegate):
             validator = DoubleValidator(editor, min=0.95, max=1.)
         else:
             validator = DoubleValidator(editor, min=0., max=1.)
-            validator.setExclusiveMin(True)
+            # validator.setExclusiveMin(True)
         editor.setValidator(validator)
         return editor
 
 
     def setEditorData(self, editor, index):
+        editor.setAutoFillBackground(True)
         value = from_qvariant(index.model().data(index, Qt.DisplayRole), to_text_string)
         editor.setText(value)
 
@@ -255,6 +260,7 @@ class RhsReconstructionDelegate(QItemDelegate):
 
 
     def setEditorData(self, editor, index):
+        editor.setAutoFillBackground(True)
         value = from_qvariant(index.model().data(index, Qt.DisplayRole), to_text_string)
         editor.setText(value)
 
@@ -284,19 +290,23 @@ class SolverDelegate(QItemDelegate):
             validator.setExclusiveMin(True)
         elif (index.column() == 2 or index.column() == 4):
             validator = IntValidator(editor, min=1)
+        elif index.column() == 5:
+            validator = DoubleValidator(editor, min=0.)
+            validator.setExclusiveMin(True)
         editor.setValidator(validator)
         editor.installEventFilter(self)
         return editor
 
 
     def setEditorData(self, editor, index):
+        editor.setAutoFillBackground(True)
         value = from_qvariant(index.model().data(index, Qt.DisplayRole), to_text_string)
         editor.setText(value)
 
 
     def setModelData(self, editor, model, index):
         if editor.validator().state == QValidator.Acceptable:
-            if index.column() == 3:
+            if index.column() == 3 or index.column() == 5:
                 value = from_qvariant(editor.text(), float)
             elif (index.column() == 2 or index.column() == 4):
                 value = from_qvariant(editor.text(), int)
@@ -493,12 +503,11 @@ class StandardItemModelSolver(QStandardItemModel):
     """
     Model associated with a QTableView.
     """
-    def __init__(self, NPE, SM):
+    def __init__(self, NPE):
         """
         """
         QStandardItemModel.__init__(self)
         self.NPE = NPE
-        self.SM = SM
         self.setColumnCount(6)
         self.dataSolver = []
         # list of items to be disabled in the view
@@ -507,9 +516,11 @@ class StandardItemModelSolver(QStandardItemModel):
 
 
     def populateModel(self):
-        self.dicoV2M= {"Multigrid"              : 'multigrid',
+        self.dicoV2M= {"Multigrid, V-cycle"     : 'multigrid',
+                       "Multigrid, K-cycle"     : 'multigrid_k_cycle',
                        "Conjugate gradient"     : 'conjugate_gradient',
-                       "Inexact conjugate gradient"     : 'inexact_conjugate_gradient',
+                       "Flexible conjugate gradient" : 'flexible_conjugate_gradient',
+                       "Inexact conjugate gradient"  : 'inexact_conjugate_gradient',
                        "Jacobi"                 : 'jacobi',
                        "BiCGstab"               : 'bi_cgstab',
                        "BiCGstab2"              : 'bi_cgstab2',
@@ -520,9 +531,11 @@ class StandardItemModelSolver(QStandardItemModel):
                        "conjugate residual"     : "PCR3",
                        "None"                   : "none",
                        "Polynomial"             : "polynomial"}
-        self.dicoM2V= {"multigrid"              : 'Multigrid',
+        self.dicoM2V= {"multigrid"              : 'Multigrid, V-cycle',
+                       "multigrid_k_cycle"      : 'Multigrid, K-cycle',
                        "conjugate_gradient"     : 'Conjugate gradient',
-                       "inexact_conjugate_gradient"     : 'Inexact conjugate gradient',
+                       "inexact_conjugate_gradient"  : 'Inexact conjugate gradient',
+                       "flexible_conjugate_gradient" : 'Flexible conjugate gradient',
                        "jacobi"                 : 'Jacobi',
                        "bi_cgstab"              : 'BiCGstab',
                        "bi_cgstab2"             : 'BiCGstab2',
@@ -672,6 +685,7 @@ class MinimumDelegate(QItemDelegate):
 
 
     def setEditorData(self, editor, index):
+        editor.setAutoFillBackground(True)
         value = from_qvariant(index.model().data(index, Qt.DisplayRole), to_text_string)
         editor.setText(value)
 
@@ -708,6 +722,7 @@ class VerbosityDelegate(QItemDelegate):
 
 
     def setEditorData(self, editor, index):
+        editor.setAutoFillBackground(True)
         value = from_qvariant(index.model().data(index, Qt.DisplayRole), to_text_string)
         editor.setText(value)
 
@@ -739,6 +754,7 @@ class MaximumDelegate(QItemDelegate):
 
 
     def setEditorData(self, editor, index):
+        editor.setAutoFillBackground(True)
         value = from_qvariant(index.model().data(index, Qt.DisplayRole), to_text_string)
         editor.setText(value)
 
@@ -897,7 +913,6 @@ class NumericalParamEquationView(QWidget, Ui_NumericalParamEquationForm):
         self.case = case
         self.case.undoStopGlobal()
         self.NPE = NumericalParamEquationModel(self.case)
-        self.SM  = SteadyManagementModel(self.case)
         self.turb = TurbulenceModel(self.case)
 
         # Scheme
@@ -924,7 +939,7 @@ class NumericalParamEquationView(QWidget, Ui_NumericalParamEquationForm):
         self.tableViewScheme.setItemDelegateForColumn(5, delegateNSWRSM)
 
         # Solver
-        self.modelSolver = StandardItemModelSolver(self.NPE, self.SM)
+        self.modelSolver = StandardItemModelSolver(self.NPE)
         self.tableViewSolver.setModel(self.modelSolver)
         self.tableViewSolver.setAlternatingRowColors(True)
         self.tableViewSolver.resizeColumnToContents(0)
@@ -937,7 +952,9 @@ class NumericalParamEquationView(QWidget, Ui_NumericalParamEquationForm):
         elif QT_API == "PYQT5":
             self.tableViewSolver.horizontalHeader().setSectionResizeMode(QHeaderView.Stretch)
 
-        if self.SM.getSteadyFlowManagement() == 'on':
+        from code_saturne.Pages.TimeStepModel import TimeStepModel
+        idtvar = TimeStepModel(self.case).getTimePassing()
+        if idtvar in [-1, 2]:
             self.tableViewSolver.setColumnHidden(5, True)
 
         delegate = SolverDelegate(self.tableViewSolver)
