@@ -4,7 +4,7 @@
 
 # This file is part of Code_Saturne, a general-purpose CFD tool.
 #
-# Copyright (C) 1998-2016 EDF S.A.
+# Copyright (C) 1998-2018 EDF S.A.
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -34,7 +34,7 @@ This module contains the following classes and function:
 #-------------------------------------------------------------------------------
 
 import sys, unittest
-import os, sys, string, types
+import os, sys, types
 
 #-------------------------------------------------------------------------------
 # Application modules import
@@ -89,7 +89,6 @@ class MeshModel:
                     'msh':'gmsh',
                     'neu':'gambit',
                     'ccm':'ccm',
-                    'ngeom':'ngeom',
                     'unv':'ideas'}
 
 
@@ -149,7 +148,6 @@ class MeshModel:
                ('gmsh',    'Gmsh',             ' (*.msh)'  ),
                ('gambit',  'GAMBIT Neutral',   ' (*.neu)'  ),
                ('ccm',     'STAR-CCM+',        ' (*.ccm)'  ),
-               ('ngeom',   'pro-STAR/STAR4',   ' (*.ngeom)'),
                ('ideas',   'I-deas universal', ' (*.unv)'  )]
 
         return lst
@@ -170,7 +168,6 @@ class MeshModel:
                ("GMSH files",                "*.msh"  ),
                ("GAMBIT Neutral files",      "*.neu"  ),
                ("STAR-CCM+",                 "*.ccm"  ),
-               ("pro-STAR/STAR4 files",      "*.ngeom"),
                ("I-deas universal files",    "*.unv"  )]
 
         return lst
@@ -198,7 +195,7 @@ class SolutionDomainModel(MeshModel, Model):
         self.node_join       = self.node_ecs.xmlInitNode('joining')
         self.node_perio      = self.node_ecs.xmlInitNode('periodicity')
         self.node_thinwall   = self.node_ecs.xmlInitNode('thin_walls')
-        self.node_extrude    = self.node_ecs.xmlInitNode('extrude_meshes')
+        self.node_extrude    = self.node_ecs.xmlInitNode('extrusion')
 
 
 #************************* Private methods *****************************
@@ -1921,7 +1918,6 @@ class MeshModelTestCase(unittest.TestCase):
                        ("toto.med",      "med")  ,
                        ("toto.msh.gz",   "msh")  ,
                        ("toto.neu",      "neu")  ,
-                       ("toto.ngeom.gz", "ngeom"),
                        ("toto.unv.gz",   "unv")  ,
                        ("toto",          "")     ,
                        ("toto.gz",       "")     ]
