@@ -127,7 +127,7 @@ void CS_PROCF (dflsui, DFLSUI)
  * integer          iisuit      : --> : 0 if no restart required, 1 otherwise
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF (reqsui, RESSUI)
+void CS_PROCF (reqsui, REQSUI)
 (
  cs_int_t   *iisuit
 );
@@ -200,6 +200,16 @@ cs_restart_checkpoint_set_defaults(int     nt_interval,
                                    double  t_interval,
                                    double  wt_interval);
 
+/*----------------------------------------------------------------------------
+ * Define last forced checkpoint time step
+ *
+ * parameters
+ *   nt_last <-- last time step for forced checkpoint
+ *----------------------------------------------------------------------------*/
+
+void
+cs_restart_checkpoint_set_last_ts(int  nt_last);
+
 /*----------------------------------------------------------------------------
  * Define next forced checkpoint time step
  *
