@@ -72,7 +72,7 @@ implicit none
 
 character(len=80) :: f_label, f_name, s_name, s_label
 integer           :: ii, ivar, isorb, keysrb, igwfpr, keypre, ischcp
-integer           :: idim1, idim3, idim6, iflid
+integer           :: idim1, idim3, idim6, iflid, k_restart_id
 integer           :: type_flag, post_flag, location_id
 logical           :: has_previous
 
@@ -188,6 +188,9 @@ call add_property_field_1d('fourier_number', 'Fourier Number', ifour)
 
 if (ippmod(icompf).lt.0.and.ippmod(idarcy).lt.0) then
   call add_property_field_1d('total_pressure', 'Total Pressure', iprtot)
+  ! Save total pressure in auxiliary restart file
+  call field_get_key_id("restart_file", k_restart_id)
+  call field_set_key_int(iprtot, k_restart_id, RESTART_AUXILIARY)
 else if (ippmod(idarcy).ge.0.and.darcy_gravity.ge.1) then
   call add_property_field_1d('total_pressure', 'Pressure head', iprtot)
 endif
