@@ -187,9 +187,9 @@ integer          f_id
 integer          icvflb
 integer          ivoid(1)
 
-double precision residu, phydr0
-double precision ardtsr, arsr  , unsara, thetap
-double precision dtsrom, unsvom, romro0
+double precision residu, phydr0, rnormp
+double precision ardtsr, arsr  , thetap
+double precision dtsrom
 double precision epsrgp, climgp, extrap, epsilp
 double precision drom  , dronm1, relaxp
 double precision hint, qimp, qimpv(3), epsrsp, blencp
@@ -229,7 +229,8 @@ double precision, allocatable, dimension(:,:), target :: tpusro
 double precision, dimension(:), pointer :: viscap
 double precision, dimension(:,:), pointer :: vitenp
 double precision, dimension(:), pointer :: imasfl, bmasfl
-double precision, dimension(:), pointer :: brom, crom, croma
+double precision, dimension(:), pointer :: brom, crom, croma, broma
+double precision, dimension(:), pointer :: brom_eos, crom_eos
 double precision, dimension(:), pointer :: cvar_pr
 double precision, dimension(:), pointer :: cpro_divu
 double precision, dimension(:), pointer :: cpro_wgrec_s
@@ -237,7 +238,13 @@ double precision, dimension(:,:), pointer :: cpro_wgrec_v
 double precision, dimension(:), pointer :: c_estim_der
 double precision, dimension(:), pointer :: cpro_tsrho
 double precision, allocatable, dimension(:) :: surfbm, dphi
+double precision, allocatable, dimension(:) :: ipro_visc, bpro_visc
+double precision, allocatable, dimension(:) :: cpro_visc
+double precision, allocatable, dimension(:,:) :: cpro_vitenp
 double precision, allocatable, dimension(:,:) :: trav
+double precision, dimension(:,:), pointer :: cpro_poro_div_duq
+double precision, dimension(:), pointer :: cpro_rho_mass, bpro_rho_mass
+double precision, dimension(:), allocatable, target :: cpro_rho_tc, bpro_rho_tc
 
 !===============================================================================
 
@@ -293,8 +300,8 @@ call field_get_id_try("predicted_vel_divergence", f_id)
 if (f_id.ge.0) then
   call field_get_val_s(f_id, cpro_divu)
 else
- allocate(divu(ncelet))
- cpro_divu => divu
+  allocate(divu(ncelet))
+  cpro_divu => divu
 endif
 
 ! --- Writing
@@ -311,11 +318,49 @@ call field_get_coefaf_s(ivarfl(ipr), coefaf_p)
 call field_get_coefbf_s(ivarfl(ipr), coefbf_p)
 
 ! --- Physical quantities
-call field_get_val_s(icrom, crom)
-if (icalhy.eq.1.or.idilat.gt.1) then
+call field_get_val_s(icrom, crom_eos)
+if (icalhy.eq.1.or.idilat.gt.1.or.irovar.eq.1) then
   call field_get_val_prev_s(icrom, croma)
 endif
-call field_get_val_s(ibrom, brom)
+call field_get_val_s(ibrom, brom_eos)
+if (irovar.eq.1) then
+  call field_get_val_prev_s(ibrom, broma)
+endif
+
+if (irovar.eq.1) then
+  call field_get_id("density_mass", f_id)
+  call field_get_val_s(f_id, cpro_rho_mass)
+  call field_get_id("boundary_density_mass", f_id)
+  call field_get_val_s(f_id, bpro_rho_mass)
+
+  ! Time interpolated density
+  if (vcopt_u%thetav .lt. 1.d0 .and. iterns.gt.1) then
+    allocate(cpro_rho_tc(ncelet))
+    allocate(bpro_rho_tc(nfabor))
+
+    do iel = 1, ncelet
+      cpro_rho_tc(iel) = vcopt_u%thetav * cpro_rho_mass(iel) &
+        + (1.d0 - vcopt_u%thetav) * croma(iel)
+    enddo
+
+    crom => cpro_rho_tc
+
+    do ifac = 1, nfabor
+      bpro_rho_tc(ifac) = vcopt_u%thetav * bpro_rho_mass(ifac) &
+        + (1.d0 - vcopt_u%thetav) * broma(ifac)
+    enddo
+
+    brom => bpro_rho_tc
+
+  else
+    crom => cpro_rho_mass
+    brom => bpro_rho_mass
+  endif
+
+else
+  crom => crom_eos
+  brom => brom_eos
+endif
 
 call field_get_val_s(ivarfl(ipr), cvar_pr)
 
@@ -781,6 +826,7 @@ allocate(gradp(3,ncelet))
 iccocg = 1
 iprev  = 0
 inc    = 1
+call grdpor(inc)
 
 ! Pressure gradient
 ! NB: for the VOF algo. the weighting is automatically done
@@ -789,13 +835,22 @@ call field_gradient_potential(ivarfl(ipr), iprev, imrgra, inc,    &
                               iccocg, iphydr,                     &
                               frcxt, gradp)
 
-if (iphydr.eq.1) then
+if (iphydr.eq.1.and.iporos.eq.3) then
+
+  call field_get_val_v_by_name("poro_div_duq", cpro_poro_div_duq)
   do iel = 1, ncel
     do isou = 1, 3
-      trav(isou, iel) = gradp(isou, iel) - frcxt(isou ,iel)
+      trav(isou, iel) = gradp(isou, iel) - frcxt(isou, iel) &
+        - cpro_poro_div_duq(isou, iel)
     enddo
   enddo
 
+else if (iphydr.eq.1) then
+  do iel = 1, ncel
+    do isou = 1, 3
+      trav(isou, iel) = gradp(isou, iel) - frcxt(isou, iel)
+    enddo
+  enddo
 else
   do iel = 1, ncel
     do isou = 1, 3
@@ -922,6 +977,9 @@ call inimav &
 if (iphydr.eq.1) then
   init   = 0
   inc    = 0
+
+  call grdpor(inc)
+
   iccocg = 1
   nswrgp = vcopt_p%nswrgr
   imligp = vcopt_p%imligr
@@ -939,7 +997,7 @@ if (iphydr.eq.1) then
    coefbf_p ,                                                     &
    imasfl , bmasfl ,                                              &
    viscf  , viscb  ,                                              &
-   viscap     , viscap     , viscap     )
+   viscap , viscap , viscap     )
 
   ! Tensor diffusivity
   else if (iand(vcopt_p%idften, ANISOTROPIC_DIFFUSION).ne.0) then
@@ -959,6 +1017,7 @@ endif
 
 init   = 0
 inc    = 1
+call grdpor(inc)
 iccocg = 1
 
 !----------------------
@@ -966,13 +1025,16 @@ iccocg = 1
 !----------------------
 if (arak.gt.0.d0) then
 
-  ! --- Prise en compte de Arak : la viscosite face est multipliee
-  !       Le pas de temps aussi. On retablit plus bas.
+  allocate(ipro_visc(nfac))
+  allocate(bpro_visc(nfabor))
+
+  ! --- Prise en compte de Arak: la viscosite face est multipliee
+  !       Le pas de temps aussi.
   do ifac = 1, nfac
-    viscf(ifac) = arak*viscf(ifac)
+    ipro_visc(ifac) = arak*viscf(ifac)
   enddo
   do ifac = 1, nfabor
-    viscb(ifac) = arak*viscb(ifac)
+    bpro_visc(ifac) = arak*viscb(ifac)
   enddo
 
   ! On annule la viscosite facette pour les faces couplees pour ne pas modifier
@@ -981,7 +1043,7 @@ if (arak.gt.0.d0) then
   if (nbrcpl.gt.0) then
     do ifac = 1, nfabor
       if (itypfb(ifac).eq.icscpd) then
-        viscb(ifac) = 0.d0
+        bpro_visc(ifac) = 0.d0
       endif
     enddo
   endif
@@ -989,8 +1051,11 @@ if (arak.gt.0.d0) then
   ! Scalar diffusivity
   !-------------------
   if (iand(vcopt_p%idften, ISOTROPIC_DIFFUSION).ne.0) then
+
+    allocate(cpro_visc(ncelet))
+
     do iel = 1, ncel
-      viscap(iel) = arak*viscap(iel)
+      cpro_visc(iel) = arak*viscap(iel)
     enddo
 
     nswrgp = vcopt_p%nswrgr
@@ -1007,8 +1072,8 @@ if (arak.gt.0.d0) then
    frcxt  ,                                                                    &
    cvar_pr,                                                                    &
    coefa_p, coefb_p, coefaf_p        , coefbf_p        ,                       &
-   viscf  , viscb  ,                                                           &
-   viscap ,                                                                    &
+   ipro_visc      , bpro_visc      ,                                           &
+   cpro_visc ,                                                                 &
    imasfl , bmasfl )
 
     ! Projection du terme source pour oter la partie hydrostat de la pression
@@ -1035,30 +1100,27 @@ if (arak.gt.0.d0) then
    frcxt  ,                                                       &
    cofbfp ,                                                       &
    imasfl , bmasfl ,                                              &
-   viscf  , viscb  ,                                              &
-   viscap     , viscap     , viscap     )
+   ipro_visc       , bpro_visc  ,                                 &
+   cpro_visc, cpro_visc, cpro_visc    )
 
       deallocate(cofbfp)
 
     endif
 
-    ! --- Correction du pas de temps
-    unsara = 1.d0/arak
-    do iel = 1, ncel
-      viscap(iel) = viscap(iel)*unsara
-    enddo
+    deallocate(cpro_visc)
 
   ! Tensor diffusivity
   !-------------------
   else if (iand(vcopt_p%idften, ANISOTROPIC_DIFFUSION).ne.0) then
 
+    allocate(cpro_vitenp(6, ncelet))
     do iel = 1, ncel
-      vitenp(1,iel) = arak*vitenp(1,iel)
-      vitenp(2,iel) = arak*vitenp(2,iel)
-      vitenp(3,iel) = arak*vitenp(3,iel)
-      vitenp(4,iel) = arak*vitenp(4,iel)
-      vitenp(5,iel) = arak*vitenp(5,iel)
-      vitenp(6,iel) = arak*vitenp(6,iel)
+      cpro_vitenp(1,iel) = arak*vitenp(1,iel)
+      cpro_vitenp(2,iel) = arak*vitenp(2,iel)
+      cpro_vitenp(3,iel) = arak*vitenp(3,iel)
+      cpro_vitenp(4,iel) = arak*vitenp(4,iel)
+      cpro_vitenp(5,iel) = arak*vitenp(5,iel)
+      cpro_vitenp(6,iel) = arak*vitenp(6,iel)
     enddo
 
     nswrgp = vcopt_p%nswrgr
@@ -1077,8 +1139,8 @@ if (arak.gt.0.d0) then
    frcxt  ,                                                                &
    cvar_pr,                                                                &
    coefa_p , coefb_p , coefaf_p , coefbf_p ,                               &
-   viscf  , viscb  ,                                                       &
-   vitenp ,                                                                &
+   ipro_visc        , bpro_visc ,                                          &
+   cpro_vitenp      ,                                                      &
    weighf , weighb ,                                                       &
    imasfl , bmasfl )
 
@@ -1104,8 +1166,8 @@ if (arak.gt.0.d0) then
    ( init   , nswrgp , ircflp ,                                     &
      frcxt  ,                                                       &
      cofbfp ,                                                       &
-     viscf  , viscb  ,                                              &
-     vitenp ,                                                       &
+     ipro_visc  , bpro_visc ,                                       &
+     cpro_vitenp ,                                                  &
      weighf ,                                                       &
      imasfl, bmasfl )
 
@@ -1113,69 +1175,12 @@ if (arak.gt.0.d0) then
 
     endif
 
-    ! --- Correction du pas de temps
-    unsara = 1.d0/arak
-    do iel = 1, ncel
-      vitenp(1,iel) = unsara*vitenp(1,iel)
-      vitenp(2,iel) = unsara*vitenp(2,iel)
-      vitenp(3,iel) = unsara*vitenp(3,iel)
-      vitenp(4,iel) = unsara*vitenp(4,iel)
-      vitenp(5,iel) = unsara*vitenp(5,iel)
-      vitenp(6,iel) = unsara*vitenp(6,iel)
-    enddo
+    deallocate(cpro_vitenp)
 
   endif
 
-  ! --- Correction de la viscosite aux faces
-  do ifac = 1, nfac
-    viscf(ifac) = viscf(ifac)*unsara
-  enddo
-  do ifac = 1, nfabor
-    viscb(ifac) = viscb(ifac)*unsara
-  enddo
-
-  ! If Saturne/Saturne coupling, re-set the boundary face viscosity to
-  ! the non-zero value
-  if (nbrcpl.gt.0) then
-    if (vcopt_p%idiff.ge.1) then
-
-      !Scalar diffusivity
-      if (iand(vcopt_p%idften, ISOTROPIC_DIFFUSION).ne.0) then
-
-        if (ivofmt.lt.0) then
-          imvisp = imvisf
-        else
-          imvisp = 1
-        endif
-
-        call viscfa &
-        !==========
-      ( imvisp ,            &
-        viscap ,            &
-        viscf  , viscb  )
-
-      ! Tensor diffusivity
-      else if (iand(vcopt_p%idften, ANISOTROPIC_DIFFUSION).ne.0) then
-
-        iwarnp = vcopt_p%iwarni
-
-        call vitens &
-        !==========
-       ( vitenp , iwarnp ,             &
-         weighf , weighb ,             &
-         viscf  , viscb  )
-
-      endif
-    else
-      do ifac = 1, nfac
-        viscf(ifac) = 0.d0
-      enddo
-      do ifac = 1, nfabor
-        viscb(ifac) = 0.d0
-      enddo
-    endif
-
-  endif
+  deallocate(ipro_visc)
+  deallocate(bpro_visc)
 
 endif
 
@@ -1326,10 +1331,13 @@ endif
 
 ! --- Source term associated to the mass aggregation
 if (idilat.eq.2.or.idilat.eq.3) then
+
+  ! Add source term
   do iel = 1, ncel
-    drom = crom(iel) - croma(iel)
+    drom = crom_eos(iel) - croma(iel)
     cpro_divu(iel) = cpro_divu(iel) + drom*cell_f_vol(iel)/dt(iel)
   enddo
+
 endif
 
 ! ---> Termes sources Lagrangien
@@ -1425,7 +1433,9 @@ rnormp = sqrt(cs_gdot(ncel,res,res))
 if (vcopt_p%iwarni.ge.2) then
   write(nfecra,1300)chaine(1:16) ,rnormp
 endif
-sinfo%nbivar = 0
+if (iterns.le.1) then
+  sinfo%nbivar = 0
+endif
 
 ! Pressure derive for the log
 if (rnormp.lt.epzero) then
@@ -1878,6 +1888,19 @@ else if (iand(vcopt_p%idften, ANISOTROPIC_DIFFUSION).ne.0) then
 
 endif
 
+! Update density (which is coherent with the mass)
+!-------------------------------------------------
+
+if (irovar.eq.1) then
+  do iel = 1, ncelet
+    cpro_rho_mass(iel) = crom_eos(iel)
+  enddo
+
+  do ifac = 1, nfabor
+    bpro_rho_mass(ifac) = brom_eos(ifac)
+  enddo
+endif
+
 !===============================================================================
 ! 6. Suppression of the mesh hierarchy
 !===============================================================================
@@ -2282,6 +2305,8 @@ if (ivofmt.ge.0.or.idilat.eq.4) then
   if (allocated(xunsro)) deallocate(xunsro)
   if (allocated(tpusro)) deallocate(tpusro)
 endif
+if (allocated(cpro_rho_tc)) deallocate(cpro_rho_tc)
+if (allocated(bpro_rho_tc)) deallocate(bpro_rho_tc)
 
 !--------
 ! Formats
