@@ -36,7 +36,6 @@
 #include "cs_cdo_local.h"
 #include "cs_cdo_quantities.h"
 #include "cs_param.h"
-#include "cs_time_step.h"
 #include "cs_xdef.h"
 
 /*----------------------------------------------------------------------------*/
@@ -61,14 +60,12 @@ BEGIN_C_DECLS
  *
  * \param[in]  quant       additional mesh quantities struct.
  * \param[in]  connect     pointer to a cs_cdo_connect_t struct.
- * \param[in]  time_step   pointer to a time step structure
  */
 /*----------------------------------------------------------------------------*/
 
 void
 cs_evaluate_set_shared_pointers(const cs_cdo_quantities_t    *quant,
-                                const cs_cdo_connect_t       *connect,
-                                const cs_time_step_t         *time_step);
+                                const cs_cdo_connect_t       *connect);
 
 /*----------------------------------------------------------------------------*/
 /*!
@@ -77,6 +74,7 @@ cs_evaluate_set_shared_pointers(const cs_cdo_quantities_t    *quant,
  *
  * \param[in]      dof_flag    indicate where the evaluation has to be done
  * \param[in]      def         pointer to a cs_xdef_t structure
+ * \param[in]      time_eval   physical time at which one evaluates the term
  * \param[in, out] retval      pointer to the computed values
  */
 /*----------------------------------------------------------------------------*/
@@ -84,7 +82,8 @@ cs_evaluate_set_shared_pointers(const cs_cdo_quantities_t    *quant,
 void
 cs_evaluate_density_by_analytic(cs_flag_t           dof_flag,
                                 const cs_xdef_t    *def,
-                                double              retval[]);
+                                cs_real_t           time_eval,
+                                cs_real_t           retval[]);
 
 /*----------------------------------------------------------------------------*/
 /*!
@@ -101,7 +100,7 @@ cs_evaluate_density_by_analytic(cs_flag_t           dof_flag,
 void
 cs_evaluate_density_by_value(cs_flag_t          dof_flag,
                              const cs_xdef_t   *def,
-                             double             retval[]);
+                             cs_real_t          retval[]);
 
 /*----------------------------------------------------------------------------*/
 /*!
@@ -110,6 +109,7 @@ cs_evaluate_density_by_value(cs_flag_t          dof_flag,
  *
  * \param[in]      dof_flag    indicate where the evaluation has to be done
  * \param[in]      def         pointer to a cs_xdef_t pointer
+ * \param[in]      time_eval   physical time at which one evaluates the term
  * \param[in, out] retval      pointer to the computed values
  */
 /*----------------------------------------------------------------------------*/
@@ -117,24 +117,28 @@ cs_evaluate_density_by_value(cs_flag_t          dof_flag,
 void
 cs_evaluate_potential_by_analytic(cs_flag_t           dof_flag,
                                   const cs_xdef_t    *def,
-                                  double              retval[]);
+                                  cs_real_t           time_eval,
+                                  cs_real_t           retval[]);
 
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief  Define a value to each DoF in the case of a potential field in order
  *         to put a given quantity inside the volume associated to the zone
- *         attached to the given definition
+ *         related to the given definition
+ *         wvals may be NULL.
  *
  * \param[in]      dof_flag  indicate where the evaluation has to be done
  * \param[in]      def       pointer to a cs_xdef_t pointer
- * \param[in, out] retval    pointer to the computed values
+ * \param[in, out] vvals     pointer to the first array of computed values
+ * \param[in, out] wvals     pointer to the second array of computed values
  */
 /*----------------------------------------------------------------------------*/
 
 void
 cs_evaluate_potential_by_qov(cs_flag_t          dof_flag,
                              const cs_xdef_t   *def,
-                             double             retval[]);
+                             cs_real_t          vvals[],
+                             cs_real_t          wvals[]);
 
 /*----------------------------------------------------------------------------*/
 /*!
@@ -149,52 +153,95 @@ cs_evaluate_potential_by_qov(cs_flag_t          dof_flag,
 void
 cs_evaluate_potential_by_value(cs_flag_t          dof_flag,
                                const cs_xdef_t   *def,
-                               double             retval[]);
+                               cs_real_t          retval[]);
 
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief  Evaluate the average of a function on the faces
  *
- * \param[in]      dof_flag  indicate where the evaluation has to be done
  * \param[in]      def       pointer to a cs_xdef_t pointer
  * \param[in, out] retval    pointer to the computed values
  */
 /*----------------------------------------------------------------------------*/
 
 void
-cs_evaluate_average_on_faces_by_value(cs_flag_t          dof_flag,
-                                      const cs_xdef_t   *def,
-                                      double             retval[]);
+cs_evaluate_average_on_faces_by_value(const cs_xdef_t   *def,
+                                      cs_real_t          retval[]);
 
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief  Evaluate the average of a function on the faces
  *
- * \param[in]      dof_flag  indicate where the evaluation has to be done
+ * \param[in]      def        pointer to a cs_xdef_t pointer
+ * \param[in]      time_eval  physical time at which one evaluates the term
+ * \param[in, out] retval     pointer to the computed values
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_evaluate_average_on_faces_by_analytic(const cs_xdef_t   *def,
+                                         cs_real_t          time_eval,
+                                         cs_real_t          retval[]);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Evaluate the average of a function on the cells
+ *
  * \param[in]      def       pointer to a cs_xdef_t pointer
  * \param[in, out] retval    pointer to the computed values
  */
 /*----------------------------------------------------------------------------*/
 
 void
-cs_evaluate_average_on_faces_by_analytic(cs_flag_t          dof_flag,
-                                         const cs_xdef_t   *def,
-                                         double             retval[]);
+cs_evaluate_average_on_cells_by_value(const cs_xdef_t   *def,
+                                      cs_real_t          retval[]);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Evaluate the average of a function on the cells
+ *
+ * \param[in]      def       pointer to a cs_xdef_t pointer
+ * \param[in, out] retval    pointer to the computed values
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_evaluate_average_on_cells_by_array(const cs_xdef_t   *def,
+                                      cs_real_t          retval[]);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Evaluate the average of a function on the cells
+ *
+ * \param[in]      def        pointer to a cs_xdef_t pointer
+ * \param[in]      time_eval  physical time at which one evaluates the term
+ * \param[in, out] retval     pointer to the computed values
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_evaluate_average_on_cells_by_analytic(const cs_xdef_t   *def,
+                                         cs_real_t          time_eval,
+                                         cs_real_t          retval[]);
+
+/*============================================================================
+ * Inline public function prototypes
+ *============================================================================*/
 
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief  Evaluate the average of a function on the faces
  *
- * \param[in]      dof_flag  indicate where the evaluation has to be done
- * \param[in]      def       pointer to a cs_xdef_t pointer
- * \param[in, out] retval    pointer to the computed values
+ * \param[in]      def        pointer to a cs_xdef_t pointer
+ * \param[in]      time_eval  physical time at which one evaluates the term
+ * \param[in, out] retval     pointer to the computed values
  */
 /*----------------------------------------------------------------------------*/
 
 static inline void
-cs_evaluate_average_on_faces(cs_flag_t          dof_flag,
-                             const cs_xdef_t   *def,
-                             double             retval[])
+cs_evaluate_average_on_faces(const cs_xdef_t   *def,
+                             cs_real_t          time_eval,
+                             cs_real_t          retval[])
 {
   /* Sanity checks */
   assert(def != NULL);
@@ -202,11 +249,11 @@ cs_evaluate_average_on_faces(cs_flag_t          dof_flag,
   switch (def->type) {
 
   case CS_XDEF_BY_VALUE:
-    cs_evaluate_average_on_faces_by_value(dof_flag, def, retval);
+    cs_evaluate_average_on_faces_by_value(def, retval);
     break;
 
   case CS_XDEF_BY_ANALYTIC_FUNCTION:
-    cs_evaluate_average_on_faces_by_analytic(dof_flag, def, retval);
+    cs_evaluate_average_on_faces_by_analytic(def, time_eval, retval);
     break;
 
   default:
@@ -219,61 +266,16 @@ cs_evaluate_average_on_faces(cs_flag_t          dof_flag,
 /*!
  * \brief  Evaluate the average of a function on the cells
  *
- * \param[in]      dof_flag  indicate where the evaluation has to be done
- * \param[in]      def       pointer to a cs_xdef_t pointer
- * \param[in, out] retval    pointer to the computed values
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_evaluate_average_on_cells_by_value(cs_flag_t          dof_flag,
-                                      const cs_xdef_t   *def,
-                                      double             retval[]);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Evaluate the average of a function on the cells
- *
- * \param[in]      dof_flag  indicate where the evaluation has to be done
- * \param[in]      def       pointer to a cs_xdef_t pointer
- * \param[in, out] retval    pointer to the computed values
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_evaluate_average_on_cells_by_array(cs_flag_t          dof_flag,
-                                      const cs_xdef_t   *def,
-                                      double             retval[]);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Evaluate the average of a function on the cells
- *
- * \param[in]      dof_flag  indicate where the evaluation has to be done
- * \param[in]      def       pointer to a cs_xdef_t pointer
- * \param[in, out] retval    pointer to the computed values
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_evaluate_average_on_cells_by_analytic(cs_flag_t          dof_flag,
-                                         const cs_xdef_t   *def,
-                                         double             retval[]);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Evaluate the average of a function on the cells
- *
- * \param[in]      dof_flag  indicate where the evaluation has to be done
- * \param[in]      def       pointer to a cs_xdef_t pointer
- * \param[in, out] retval    pointer to the computed values
+ * \param[in]      def        pointer to a cs_xdef_t pointer
+ * \param[in]      time_eval  physical time at which one evaluates the term
+ * \param[in, out] retval     pointer to the computed values
  */
 /*----------------------------------------------------------------------------*/
 
 static inline void
-cs_evaluate_average_on_cells(cs_flag_t          dof_flag,
-                             const cs_xdef_t   *def,
-                             double             retval[])
+cs_evaluate_average_on_cells(const cs_xdef_t   *def,
+                             cs_real_t          time_eval,
+                             cs_real_t          retval[])
 {
   /* Sanity checks */
   assert(def != NULL);
@@ -281,15 +283,15 @@ cs_evaluate_average_on_cells(cs_flag_t          dof_flag,
   switch (def->type) {
 
   case CS_XDEF_BY_VALUE:
-    cs_evaluate_average_on_cells_by_value(dof_flag, def, retval);
+    cs_evaluate_average_on_cells_by_value(def, retval);
     break;
 
   case CS_XDEF_BY_ANALYTIC_FUNCTION:
-    cs_evaluate_average_on_cells_by_analytic(dof_flag, def, retval);
+    cs_evaluate_average_on_cells_by_analytic(def, time_eval, retval);
     break;
 
   case CS_XDEF_BY_ARRAY:
-    cs_evaluate_average_on_cells_by_array(dof_flag, def, retval);
+    cs_evaluate_average_on_cells_by_array(def, retval);
 
   default:
     bft_error(__FILE__, __LINE__, 0, " %s: Case not handled yet.", __func__);
@@ -297,6 +299,22 @@ cs_evaluate_average_on_cells(cs_flag_t          dof_flag,
   }
 }
 
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Evaluate the integral over the full computational domain of a
+ *         quantity defined by an array
+ *
+ * \param[in]      array_loc  flag indicating where are located values
+ * \param[in]      array_val  array of values
+ *
+ * \return the value of the integration
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_real_t
+cs_evaluate_scal_domain_integral_by_array(cs_flag_t         array_loc,
+                                          const cs_real_t  *array_val);
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
