@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2016 EDF S.A.
+! Copyright (C) 1998-2018 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -47,9 +47,9 @@ subroutine cpltcl &
 !__________________!____!_____!________________________________________________!
 ! itypfb           ! ia ! <-- ! boundary face types                            !
 ! izfppp           ! te ! <-- ! numero de zone de la face de bord              !
-! (nfabor)         !    !     !  pour le module phys. part.                    !
+!                  !    !     !  pour le module phys. part.                    !
 ! rcodcl           ! tr ! --> ! valeur des conditions aux limites              !
-!  (nfabor,nvarcl) !    !     !  aux faces de bord                             !
+!                  !    !     !  aux faces de bord                             !
 !                  !    !     ! rcodcl(1) = valeur du dirichlet                !
 !                  !    !     ! rcodcl(2) = valeur du coef. d'echange          !
 !                  !    !     !  ext. (infinie si pas d'echange)               !
@@ -59,7 +59,7 @@ subroutine cpltcl &
 !                  !    !     ! pour les vitesses (vistl+visct)*gradu          !
 !                  !    !     ! pour la pression             dt*gradp          !
 !                  !    !     ! pour les scalaires                             !
-!                  !    !     !        cp*(viscls+visct/sigmas)*gradt          !
+!                  !    !     !        cp*(viscls+visct/turb_schmidt)*gradt    !
 !__________________!____!_____!________________________________________________!
 
 !     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
@@ -77,6 +77,7 @@ use numvar
 use optcal
 use cstphy
 use cstnum
+use dimens, only : nvar
 use entsor
 use parall
 use ppppar
@@ -87,6 +88,8 @@ use ppincl
 use ppcpfu
 use mesh
 use field
+use cs_c_bindings
+
 !===============================================================================
 
 implicit none
@@ -96,7 +99,7 @@ implicit none
 integer          itypfb(nfabor)
 integer          izfppp(nfabor)
 
-double precision rcodcl(nfabor,nvarcl,3)
+double precision rcodcl(nfabor,nvar,3)
 
 ! Local variables
 
@@ -104,7 +107,7 @@ integer          ii, ifac, izone, mode, iel, ige, iok
 integer          icha, icke
 integer          nbrval
 double precision qisqc, viscla, d2s3, uref2, rhomoy, dhy, xiturb
-double precision ustar2, xkent, xeent, t1
+double precision t1
 double precision h1    (nozppm)
 double precision qimpc (nozppm) , qcalc(nozppm)
 double precision coefe (ngazem)
@@ -119,7 +122,7 @@ double precision, dimension(:), pointer :: viscl
 
 
 call field_get_val_s(ibrom, brom)
-call field_get_val_s(iprpfl(iviscl), viscl)
+call field_get_val_s(iviscl, viscl)
 
 d2s3 = 2.d0/3.d0
 
@@ -302,50 +305,22 @@ do ifac = 1, nfabor
       icke   = icalke(izone)
       dhy    = dh(izone)
       xiturb = xintur(izone)
-      ustar2 = 0.d0
-      xkent = epzero
-      xeent = epzero
+
       if (icke.eq.1) then
-        call keendb                                               &
-        !==========
-        ( uref2, dhy, rhomoy, viscla, cmu, xkappa,                &
-          ustar2, xkent, xeent )
+        !   Calculation of turbulent inlet conditions using
+        !     standard laws for a circular pipe
+        !     (their initialization is not needed here but is good practice).
+        call turbulence_bc_inlet_hyd_diam(ifac, uref2, dhy, rhomoy, viscla,  &
+                                          rcodcl)
       else if (icke.eq.2) then
-        call keenin                                               &
-        !==========
-        ( uref2, xiturb, dhy, cmu, xkappa, xkent, xeent )
-      endif
 
-      if (itytur.eq.2) then
+        ! Calculation of turbulent inlet conditions using
+        !   the turbulence intensity and standard laws for a circular pipe
+        !   (their initialization is not needed here but is good practice)
 
-        rcodcl(ifac,ik,1)  = xkent
-        rcodcl(ifac,iep,1) = xeent
+        call turbulence_bc_inlet_turb_intensity(ifac, uref2, xiturb, dhy,  &
+                                                rcodcl)
 
-      elseif (itytur.eq.3) then
-
-        rcodcl(ifac,ir11,1) = d2s3*xkent
-        rcodcl(ifac,ir22,1) = d2s3*xkent
-        rcodcl(ifac,ir33,1) = d2s3*xkent
-        rcodcl(ifac,ir12,1) = 0.d0
-        rcodcl(ifac,ir13,1) = 0.d0
-        rcodcl(ifac,ir23,1) = 0.d0
-        rcodcl(ifac,iep,1)  = xeent
-
-      elseif (iturb.eq.50) then
-
-        rcodcl(ifac,ik,1)   = xkent
-        rcodcl(ifac,iep,1)  = xeent
-        rcodcl(ifac,iphi,1) = d2s3
-        rcodcl(ifac,ifb,1)  = 0.d0
-
-      elseif (iturb.eq.60) then
-
-        rcodcl(ifac,ik,1)   = xkent
-        rcodcl(ifac,iomg,1) = xeent/cmu/xkent
-
-      elseif (iturb.eq.70) then
-
-        rcodcl(ifac,inusa,1) = cmu*xkent**2/xeent
 
       endif
 
