@@ -2,7 +2,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2016 EDF S.A.
+! Copyright (C) 1998-2018 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -57,6 +57,7 @@ use ppppar
 use ppthch
 use ppincl
 use ctincl
+use cs_c_bindings
 
 !===============================================================================
 
@@ -65,7 +66,8 @@ implicit none
 ! Local variables
 
 integer jj, isc
-double precision cpa,cpe,cpv,hv0,rhoe,visc,conduc
+
+type(var_cal_opt) :: vcopt
 
 !===============================================================================
 
@@ -73,46 +75,42 @@ double precision cpa,cpe,cpv,hv0,rhoe,visc,conduc
 ! 1. Transported variables
 !===============================================================================
 
-irovar = 1
-ivivar = 0
-
-! --> Physical or numerical properties specific to scalars
+irovar = 1 ! Variable density
+ivivar = 0 ! Constant molecular viscosity
 
 do isc = 1, nscapp
 
   jj = iscapp(isc)
 
-  if (iscavr(jj).le.0) then
+  if (iscavr(jj).le.0) then  ! iscavr = 0 for scalars which are not mean square errors of other scalars
     visls0(jj) = viscl0
   endif
 
-  blencv(isca(jj)) = 1.d0
+  call field_get_key_struct_var_cal_opt(ivarfl(isca(jj)), vcopt)
+
+  ! Upwind for scalars in the packing zones
+  if (jj.eq.iyml .or. jj.eq.ihml) then
+    vcopt%blencv = 0.d0
+    vcopt%idiff  = 0
+    vcopt%idifft = 0
+  else
+    vcopt%blencv = 1.d0
+  endif
+
+  ! Set beta limiter to maintain y_p in the limits
+  if (jj.eq.iy_p_l) then
+    vcopt%isstpc = 2
+  endif
+
+  call field_set_key_struct_var_cal_opt(ivarfl(isca(jj)), vcopt)
 
 enddo
 
-! Postprocessing output
-
-ichrze = 1
-
-! Air properties
-
-cpa    = 1006.0d0
-cpv    = 1831.0d0
-cpe    = 4179.0d0
-hv0    = 2501600.0d0
-rhoe   = 997.85615d0
-visc   = 1.765d-5
-conduc = 0.02493d0
-
-call ctprof(cpa, cpv, cpe, hv0, rhoe, visc, conduc, gx, gy, gz)
-!==========
-
 !===============================================================================
 ! 2. Define user settings
 !===============================================================================
 
-call uscti1
-!==========
+call cs_user_cooling_towers()
 
 return
 end subroutine
