@@ -8,7 +8,7 @@
 /*
   This file is part of Code_Saturne, a general-purpose CFD tool.
 
-  Copyright (C) 1998-2016 EDF S.A.
+  Copyright (C) 1998-2018 EDF S.A.
 
   This program is free software; you can redistribute it and/or modify it under
   the terms of the GNU General Public License as published by the Free Software
@@ -49,17 +49,11 @@ void
 cs_gui_particles_model(void);
 
 /*----------------------------------------------------------------------------;
-
  * Define lagrangian model boundary conditions
- *
- * parameters:
- *   nfabor <-- number of boundary faces
- *   nozppm <-- max number of boundary conditions zone
  *----------------------------------------------------------------------------*/
 
 void
-cs_gui_particles_bcs(const cs_lnum_t  *nfabor,
-                     const int        *nozppm);
+cs_gui_particles_bcs(void);
 
 /*----------------------------------------------------------------------------*/
 
