@@ -4,7 +4,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2016 EDF S.A.
+! Copyright (C) 1998-2018 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -23,8 +23,6 @@
 !-------------------------------------------------------------------------------
 
 !===============================================================================
-! Purpose:
-! -------
 
 !> \file cs_user_parameters.f90
 !>
@@ -56,17 +54,7 @@
 
 !===============================================================================
 
-
-subroutine usppmo &
-!================
- ( ixmlpu )
-
-
-!===============================================================================
-! Purpose:
-! -------
-
-!> \brief User subroutine.
+!> \brief User subroutine for selection of specific physics module
 
 !> Define the use of a specific physics amongst the following:
 !>   - combustion with gas / coal / heavy fuel oil
@@ -78,7 +66,6 @@ subroutine usppmo &
 !>
 !>    Only one specific physics module can be activated at once.
 
-
 !-------------------------------------------------------------------------------
 ! Arguments
 !______________________________________________________________________________.
@@ -88,6 +75,9 @@ subroutine usppmo &
 !>                              (1 : yes, 0 : no)
 !______________________________________________________________________________!
 
+subroutine usppmo &
+ ( ixmlpu )
+
 !===============================================================================
 ! Module files
 !===============================================================================
@@ -117,16 +107,7 @@ end subroutine usppmo
 
 !===============================================================================
 
-
-subroutine usipph &
-!================
- ( ixmlpu, iturb , itherm, iale , icavit )
-
-!===============================================================================
-! Purpose:
-! --------
-
-!> \brief User subroutine for input of parameters.
+!> \brief User subroutine for input of model selection parameters.
 
 !-------------------------------------------------------------------------------
 ! Arguments
@@ -138,9 +119,13 @@ subroutine usipph &
 !> \param[in, out] iturb        turbulence model
 !> \param[in, out] itherm       thermal model
 !> \param[in, out] iale         ale module
+!> \param[in, out] ivofmt       vof method
 !> \param[in, out] icavit       cavitation model
 !______________________________________________________________________________!
 
+subroutine usipph &
+ ( ixmlpu, iturb , itherm, iale , ivofmt, icavit )
+
 !===============================================================================
 ! Module files
 !===============================================================================
@@ -155,15 +140,12 @@ implicit none
 ! Arguments
 
 integer ixmlpu
-integer iturb, itherm, iale, icavit
+integer iturb, itherm, iale, ivofmt, icavit
 
 ! Local variables
 
 !===============================================================================
 
-!===============================================================================
-
-
 !>    In this subroutine, only the parameters which already appear may
 !>    be set, to the exclusion of any other.
 !>
@@ -192,16 +174,6 @@ end subroutine usipph
 
 !===============================================================================
 
-
-subroutine usipsu &
-!================
-
- ( nmodpp )
-
-!===============================================================================
-! Purpose:
-! -------
-
 !> \brief User subroutine for the input of additional user parameters.
 !
 !-------------------------------------------------------------------------------
@@ -212,6 +184,9 @@ subroutine usipsu &
 !> \param[in]     nmodpp         number of active specific physics models
 !______________________________________________________________________________!
 
+subroutine usipsu &
+ ( nmodpp )
+
 !===============================================================================
 ! Module files
 !===============================================================================
@@ -234,7 +209,9 @@ use coincl
 use cpincl
 use field
 use cavitation
+use post
 use rotation
+use cs_c_bindings
 
 !===============================================================================
 
@@ -264,17 +241,6 @@ end subroutine usipsu
 
 !===============================================================================
 
-
-subroutine usipes &
-!================
-
- ( nmodpp )
-
-
-!===============================================================================
-! Purpose:
-! --------
-
 !> \brief User subroutine for the input of additional user parameters for
 !>        input/output.
 
@@ -286,6 +252,9 @@ subroutine usipes &
 !> \param[in]     nmodpp       number of active specific physics models
 !______________________________________________________________________________!
 
+subroutine usipes &
+ ( nmodpp )
+
 !===============================================================================
 ! Module files
 !===============================================================================
@@ -301,9 +270,11 @@ use field
 use parall
 use period
 use ihmpre
+use post
 use ppppar
 use ppthch
 use ppincl
+use cs_c_bindings
 
 !===============================================================================
 
@@ -330,14 +301,6 @@ end subroutine usipes
 !===============================================================================
 
 
-subroutine usati1
-!================
-
-
-!===============================================================================
-! Purpose:
-! --------
-
 !> \brief Initialize non-standard calculation options for the atmospheric version.
 
 !-------------------------------------------------------------------------------
@@ -346,6 +309,8 @@ subroutine usati1
 !  mode           name          role                                           !
 !______________________________________________________________________________!
 
+subroutine usati1
+
 !===============================================================================
 ! Module files
 !===============================================================================
@@ -405,7 +370,6 @@ end subroutine usati1
 
 subroutine cs_user_combustion
 
-
 !===============================================================================
 ! Module files
 !===============================================================================
@@ -444,13 +408,15 @@ end subroutine cs_user_combustion
 
 !===============================================================================
 
-!===============================================================================
-!  Purpose  :
-!  -------
 !> \brief User subroutines for input of calculation parameters,
 !>        and to initialize variables used for radiative transfer module
-!
+
 !-------------------------------------------------------------------------------
+! Arguments
+!______________________________________________________________________________.
+!  mode           name          role                                           !
+!______________________________________________________________________________!
+
 subroutine cs_f_user_radiative_transfer_param
 
 !===============================================================================
@@ -479,14 +445,6 @@ end subroutine cs_f_user_radiative_transfer_param
 
 !===============================================================================
 
-subroutine uscfx1
-!================
-
-
-!===============================================================================
-! Purpose:
-! -------
-
 !> \brief User subroutine.
 
 !> Initialize non standard options for the compressible flow scheme such
@@ -499,6 +457,8 @@ subroutine uscfx1
 !  mode           name          role                                           !
 !______________________________________________________________________________!
 
+subroutine uscfx1
+
 !===============================================================================
 ! Module files
 !===============================================================================
@@ -568,13 +528,6 @@ end subroutine uscfx1
 !===============================================================================
 
 
-subroutine uscfx2
-!================
-
-
-! Purpose:
-! -------
-
 !> \brief User subroutine.
 !>
 !> Set values for the reference volumic viscosity, the reference
@@ -588,13 +541,14 @@ subroutine uscfx2
 !> molecular viscosity is constant, its values being given in the user
 !> subroutine \ref usipsu .
 
-
 !-------------------------------------------------------------------------------
 ! Arguments
 !______________________________________________________________________________.
 !  mode           name          role                                           !
 !______________________________________________________________________________!
 
+subroutine uscfx2
+
 !===============================================================================
 ! Module files
 !===============================================================================
@@ -658,15 +612,6 @@ end subroutine uscfx2
 
 !===============================================================================
 
-
-subroutine uscti1
-!================
-
-
-!===============================================================================
-! Purpose:
-! -------
-
 !> \brief Definition of cooling tower model and exchange zones
 
 !-------------------------------------------------------------------------------
@@ -675,6 +620,8 @@ subroutine uscti1
 !  mode           name          role                                           !
 !______________________________________________________________________________!
 
+subroutine cs_user_cooling_towers
+
 !===============================================================================
 ! Module files
 !===============================================================================
@@ -720,7 +667,8 @@ endif
 '@',/,                                                            &
 '@ @@ WARNING:    stop in data input',/,                          &
 '@    =======',/,                                                 &
-'@     The user subroutine ''uscti1'' must be completed',/,       &
+'@     The user subroutine ''cs_user_cooling_towers''',/,         &
+'@     must be completed',/,                                      &
 '@     for the cooling tower module',/,                           &
 '@                                                            ',/,&
 '@',/,                                                            &
@@ -737,19 +685,13 @@ endif
 !----
 
 return
-end subroutine uscti1
+end subroutine cs_user_cooling_towers
 
 
 !===============================================================================
 
-subroutine user_darcy_ini1
-!========================
-
-!===============================================================================
-!  Purpose:
-!  --------
-
-!> \brief User routine for definition of computation parameters dealing with darcy module
+!> \brief User routine for definition of computation parameters dealing
+!>        with Darcy module
 
 !-------------------------------------------------------------------------------
 ! Arguments
@@ -757,6 +699,8 @@ subroutine user_darcy_ini1
 !  mode           name          role                                           !
 !______________________________________________________________________________!
 
+subroutine user_darcy_ini1
+
 !===============================================================================
 ! Module files
 !===============================================================================
