@@ -4,7 +4,7 @@
 
 ! This file is part of Code_Saturne, a general-purpose CFD tool.
 !
-! Copyright (C) 1998-2016 EDF S.A.
+! Copyright (C) 1998-2018 EDF S.A.
 !
 ! This program is free software; you can redistribute it and/or modify it under
 ! the terms of the GNU General Public License as published by the Free Software
@@ -52,6 +52,7 @@ use ppthch
 use ppincl
 use field
 use mesh
+use cs_c_bindings
 use darcy_module
 
 !===============================================================================
@@ -74,20 +75,24 @@ double precision kr_param, m_param, n_param, se_param
 double precision alpha_param, l_param, tmp_1, tmp_2
 double precision darcy_anisotropic_dispersion_l, darcy_anisotropic_dispersion_t
 double precision darcy_isotropic_dispersion, molecular_diffusion
-double precision velocity_norm, rho, Kd
+double precision velocity_norm, rho
 double precision ki, ki_xx, ki_yy, ki_zz, tmp_lt
 integer          iel, ii, fid
 integer          ncelt, icelt, ifcvsl
 character*80     fname
 
 integer, allocatable, dimension(:) :: lstcel
-integer, allocatable, dimension(:) :: delay_id
-double precision, dimension(:), pointer :: delay, capacity, permeability, saturation
+double precision, dimension(:), pointer :: capacity, permeability
+double precision, dimension(:), pointer :: saturation, soil_density
+double precision, dimension(:), pointer :: cpro_kd, cpro_kplus, cpro_kminus
+double precision, dimension(:), pointer :: cpro_mxsol
 double precision, dimension(:,:), pointer :: tensor_permeability, visten
 double precision, dimension(:), pointer :: cpro_vscalt
 double precision, dimension(:,:), pointer :: vel
 double precision, dimension(:), pointer :: cvar_pr
 
+type(gwf_soilwater_partition) :: sorption_scal
+
 !===============================================================================
 
 ! Index for hydraulic head (H=h+z) and darcian velocity
@@ -100,20 +105,14 @@ call field_get_val_s_by_name('capacity', capacity)
 ! Index field for the saturation table (theta)
 call field_get_val_s_by_name('saturation', saturation)
 
+! Index field for the soil density table (It is bulk density)
+call field_get_val_s_by_name('soil_density', soil_density)
+
 ! Index field for tensorial dipersion
 call field_get_val_v(ivsten, visten)
 
-! Initialisation of delay table for each solute
-allocate(delay_id(nscal))
-do ii = 1, nscal
-  ! Name of the scalar ivar
-  call field_get_name(ivarfl(isca(ii)), fname)
-  ! Index of the corresponding field
-  call field_get_id(trim(fname)//'_delay', delay_id(ii))
-enddo
-
-! Index field for delay
-call field_get_val_s(delay_id(1), delay)
+! Index field for soilwater_partition structure
+call field_get_key_struct_gwf_soilwater_partition(ivarfl(isca(1)), sorption_scal)
 
 ! Index field for diffusion (dipersion and molecular diffusion) for the transport part
 call field_get_key_int(ivarfl(isca(1)), kivisl, ifcvsl)
@@ -250,16 +249,39 @@ do iel = 1, ncel
 enddo
 !< [richards_unsat_aniso_disp]
 
-!< [richards_unsat_sorp]
-! Computation of the sorption as a delay term (K_d hypothesis)
-rho = 1.5d0
-Kd  = 1.d-1
+!< [richards_unsat_soilwater_partition]
+! Set soil density (bulk density!) for delay computation (delay = 1 + soil_density * K_d / saturation)
 do iel = 1, ncel
-  delay(iel) = 1.d0+rho*Kd/saturation(iel)
+  soil_density(iel) = 1.5d0
 enddo
-!< [richards_unsat_sorp]
 
-deallocate(delay_id)
+! Get soil-water partition structure
+call field_get_key_struct_gwf_soilwater_partition(ivarfl(isca(1)), &
+                                                  sorption_scal)
+
+! Index field for kd
+call field_get_val_s(sorption_scal%ikd, cpro_kd)
+
+! Index field for EK model parameters (kplus and kminus)
+call field_get_val_s(sorption_scal%ikp, cpro_kplus)
+call field_get_val_s(sorption_scal%ikm, cpro_kminus)
+
+! Set sorption parameters
+do iel=1, ncel
+  cpro_kd(iel) = 5.d0
+  ! if EK model is chosen, set specific parameters
+  cpro_kplus(iel) =  1.d-3
+  cpro_kminus(iel) = 1.d-4
+enddo
+
+!Index field for cpro_mxsol index (if precipitation option is activated)
+call field_get_val_s(sorption_scal%imxsol, cpro_mxsol)
+
+do iel=1, ncel
+  cpro_mxsol(iel) = 10.d0
+enddo
+
+!< [richards_unsat_soilwater_partition]
 
 !===============================================================================
 
